"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = __importDefault(require("path"));
var fs_1 = __importDefault(require("fs"));
var webpack_1 = __importDefault(require("webpack"));
var html_webpack_plugin_1 = __importDefault(require("html-webpack-plugin"));
var mini_css_extract_plugin_1 = __importDefault(require("mini-css-extract-plugin"));
var copy_webpack_plugin_1 = __importDefault(require("copy-webpack-plugin"));
var fork_ts_checker_webpack_plugin_1 = __importDefault(require("fork-ts-checker-webpack-plugin"));
var eslint_webpack_plugin_1 = __importDefault(require("eslint-webpack-plugin"));
var utils_1 = __importDefault(require("./utils"));
var ModuleFederationPlugin = require("webpack").container.ModuleFederationPlugin;
function hasTSConfig() {
    return fs_1.default.existsSync(path_1.default.resolve(process.cwd(), 'tsconfig.json'));
}
function addPlugins(basePlugins, plugins) {
    if (plugins) {
        plugins.forEach(function (plugin) {
            basePlugins.push(plugin);
        });
    }
    return basePlugins;
}
function getPlugins(rcb) {
    var basePlugins = [
        rcb.moduleFederationPlugin && new ModuleFederationPlugin(rcb.moduleFederationPlugin),
        new copy_webpack_plugin_1.default({
            patterns: [{
                    from: path_1.default.resolve('public'),
                    globOptions: { ignore: ['**/index.html'] }
                }]
        }),
        new webpack_1.default.DefinePlugin({
            'process.env': {
                NODE_ENV: JSON.stringify(utils_1.default.getEnv())
            }
        }),
        new eslint_webpack_plugin_1.default({
            eslintPath: require.resolve('eslint'),
            resolvePluginsRelativeTo: __dirname,
            baseConfig: utils_1.default.requireModule(require.resolve('./eslintrc'))
        }),
        new html_webpack_plugin_1.default({
            template: path_1.default.resolve('./public/index.html')
        }),
    ];
    if (hasTSConfig()) {
        basePlugins.push(new fork_ts_checker_webpack_plugin_1.default({
            async: true
        }));
    }
    if (utils_1.default.isDev()) {
        addPlugins(basePlugins, [
            new webpack_1.default.HotModuleReplacementPlugin(),
            new mini_css_extract_plugin_1.default({
                filename: 'css/[name].css'
            })
        ]);
    }
    if (utils_1.default.isProduction()) {
        addPlugins(basePlugins, [
            new mini_css_extract_plugin_1.default({
                filename: 'css/[name].[contenthash:8].css'
            })
        ]);
    }
    if (rcb.webpackPluginConfig && rcb.webpackPluginConfig.length > 0) {
        return __spreadArrays([basePlugins], rcb.webpackPluginConfig);
    }
    return basePlugins.filter(Boolean);
}
exports.default = getPlugins;
;
